@@ -1,30 +1,29 @@
 #' \pkg{constants}: Reference on Constants, Units and Uncertainty
 #'
-#' This package provides the 2018 version of the CODATA internationally recommended
+#' This package provides the 2022 version of the CODATA internationally recommended
 #' values of the fundamental physical constants for their use within the \R language.
 #'
 #' @author Iñaki Ucar
 #'
 #' @references
-#' Eite Tiesinga, Peter J. Mohr, David B. Newell, and Barry N. Taylor (2020).
-#' The 2018 CODATA Recommended Values of the Fundamental Physical Constants
-#' (Web Version 8.1). Database developed by J. Baker, M. Douma, and S. Kotochigova.
+#' Eite Tiesinga, Peter J. Mohr, David B. Newell, and Barry N. Taylor (2024).
+#' The 2022 CODATA Recommended Values of the Fundamental Physical Constants
+#' (Web Version 9.0). Database developed by J. Baker, M. Douma, and S. Kotochigova.
 #' Available at https://physics.nist.gov/cuu/Constants/,
 #' National Institute of Standards and Technology, Gaithersburg, MD 20899.
 #'
 #' @seealso \code{\link{codata}}, \code{\link{syms}}, \code{\link{lookup}}.
 #'
-#' @docType package
 #' @name constants-package
-NULL
+"_PACKAGE"
 
-#' CODATA Recommended Values of the Fundamental Physical Constants: 2018
+#' CODATA Recommended Values of the Fundamental Physical Constants: 2022
 #'
 #' The Committee on Data for Science and Technology (CODATA) is an interdisciplinary
 #' committee of the International Council for Science. The Task Group on Fundamental
 #' Constants periodically provides the internationally accepted set of values of
-#' the fundamental physical constants. This dataset contains the "2018 CODATA"
-#' version, published on May 2019.
+#' the fundamental physical constants. This dataset contains the "2022 CODATA"
+#' version, published on May 2024.
 #'
 #' @format An object of class \code{data.frame} with the following information
 #' for each physical constant:
@@ -32,9 +31,9 @@ NULL
 #' \code{value}, \code{uncertainty}, \code{unit}.
 #'
 #' @source
-#' Eite Tiesinga, Peter J. Mohr, David B. Newell, and Barry N. Taylor (2020).
-#' The 2018 CODATA Recommended Values of the Fundamental Physical Constants
-#' (Web Version 8.1). Database developed by J. Baker, M. Douma, and S. Kotochigova.
+#' Eite Tiesinga, Peter J. Mohr, David B. Newell, and Barry N. Taylor (2024).
+#' The 2022 CODATA Recommended Values of the Fundamental Physical Constants
+#' (Web Version 9.0). Database developed by J. Baker, M. Douma, and S. Kotochigova.
 #' Available at https://physics.nist.gov/cuu/Constants/,
 #' National Institute of Standards and Technology, Gaithersburg, MD 20899.
 #'
